pub(crate) struct PipelineAnimations {
caret: RefCell<Option<CaretAnimation>>,
}Expand description
This structure tracks the animations active for a given pipeline. Currently only caret blinking is tracked, but in the future this could perhaps track paint-side animations.
Fields
caret: RefCell<Option<CaretAnimation>>Implementations
Sourceimpl PipelineAnimations
impl PipelineAnimations
pub(crate) fn update( &self, caret_visible: bool, ) -> Option<PropertyValue<ColorF>>
pub(crate) fn handle_new_display_list( &self, caret_property_binding: Option<(PropertyBindingKey<ColorF>, ColorF)>, web_content_animator: &WebContentAnimator, )