pub(crate) struct WebContentAnimator {
event_loop_waker: Box<dyn EventLoopWaker>,
timer_refresh_driver: Rc<TimerRefreshDriver>,
caret_visible: Cell<bool>,
timer_scheduled: Cell<bool>,
need_update: Arc<AtomicBool>,
}Expand description
A struct responsible for managing paint-side animations. Currently this only handles text caret blinking, but the idea is that in the future this would handle other types of paint-side animations as well.
Note: This does not control animations requiring layout (all CSS transitions and animations currently) nor animations due to touch events such as fling.
Fields
event_loop_waker: Box<dyn EventLoopWaker>timer_refresh_driver: Rc<TimerRefreshDriver>caret_visible: Cell<bool>timer_scheduled: Cell<bool>need_update: Arc<AtomicBool>Implementations
Sourceimpl WebContentAnimator
impl WebContentAnimator
pub(crate) fn new( event_loop_waker: Box<dyn EventLoopWaker>, timer_refresh_driver: Rc<TimerRefreshDriver>, ) -> Self
pub(crate) fn schedule_timer_if_necessary(&self)
pub(crate) fn update( &self, webview_renderers: &FxHashMap<WebViewId, WebViewRenderer>, ) -> Option<Vec<PropertyValue<ColorF>>>